==> translate-toolkit_1.11.0+dfsg.orig.tar.gz: translate-toolkit-1.11.0+dfsg.orig/translate/convert/po2web2py.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright 2009-2010 Zuza Software Foundation
#
# This file is part of translate.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, see <http://www.gnu.org/licenses/>.
#
# (c) 2009 Dominic König (dominic@nursix.org)

"""Convert GNU/gettext PO files to web2py translation dictionaries (.py).

See: http://docs.translatehouse.org/projects/translate-toolkit/en/latest/commands/web2py2po.html
for examples and usage instructions.
"""

from translate.storage import factory


class po2pydict:

    def __init__(self):
        return

    def convertstore(self, inputstore, includefuzzy):
        from StringIO import StringIO
        str_obj = StringIO()

        mydict = dict()
        for unit in inputstore.units:
            if unit.isheader():
                continue
            if unit.istranslated() or (includefuzzy and unit.isfuzzy()):
                mydict[unit.source] = unit.target
            else:
                mydict[unit.source] = unit.source
                # The older convention is to prefix with "*** ":
                #mydict[unit.source] = '*** ' + unit.source

        str_obj.write('{\n')
        for source_str in mydict:
            str_obj.write("%s:%s,\n" % (repr(str(source_str)), repr(str(mydict[source_str]))))
        str_obj.write('}\n')
        str_obj.seek(0)
        return str_obj


def convertpy(inputfile, outputfile, templatefile=None, includefuzzy=False,
              outputthreshold=None):
    inputstore = factory.getobject(inputfile)

    if not convert.should_output_store(inputstore, outputthreshold):
        return False

    convertor = po2pydict()
    outputstring = convertor.convertstore(inputstore, includefuzzy)
    outputfile.write(outputstring.read())
    return 1


def main(argv=None):
    from translate.misc import stdiotell
    import sys
    sys.stdout = stdiotell.StdIOWrapper(sys.stdout)
    formats = {("po", "py"): ("py", convertpy), ("po"): ("py", convertpy)}
    parser = convert.ConvertOptionParser(formats, usetemplates=False, description=__doc__)
    parser.add_threshold_option()
    parser.add_fuzzy_option()
    parser.run(argv)


if __name__ == '__main__':
    main()

==> translate-toolkit-2.5.0.tar.gz: translate-toolkit-2.5.0/translate/convert/po2web2py.py <==
# -*- coding: utf-8 -*-
#
# Copyright 2009-2010 Zuza Software Foundation
#
# This file is part of translate.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, see <http://www.gnu.org/licenses/>.
#

"""Convert GNU/gettext PO files to web2py translation dictionaries (.py).

See: http://docs.translatehouse.org/projects/translate-toolkit/en/latest/commands/web2py2po.html
for examples and usage instructions.
"""

from io import StringIO

from translate.convert import convert
from translate.storage import factory

import six


class po2pydict(object):

    def __init__(self):
        return

    def convertstore(self, inputstore, includefuzzy):
        str_obj = StringIO()

        mydict = dict()
        for unit in inputstore.units:
            if unit.isheader():
                continue
            if unit.istranslated() or (includefuzzy and unit.isfuzzy()):
                mydict[unit.source] = unit.target
            else:
                mydict[unit.source] = unit.source.replace('@markmin\x01', '')

        str_obj.write(u'# -*- coding: utf-8 -*-\n')
        str_obj.write(u'{\n')
        for source_str, trans_str in sorted(mydict.items()):
            if six.PY2:
                source_str = source_str.encode('utf-8')
                trans_str = trans_str.encode('utf-8')
            str_obj.write(u"%s: %s,\n" % (repr(source_str), repr(trans_str)))
        str_obj.write(u'}\n')
        str_obj.seek(0)
        return str_obj


def convertpy(inputfile, outputfile, templatefile=None, includefuzzy=False,
              outputthreshold=None):
    inputstore = factory.getobject(inputfile)

    if not convert.should_output_store(inputstore, outputthreshold):
        return 0

    convertor = po2pydict()
    outputstring = convertor.convertstore(inputstore, includefuzzy)

    if six.PY2:
        outputfile.write(outputstring.read().decode('utf-8'))
    else:
        outputfile.write(bytes(outputstring.read(), 'utf-8'))
    return 1


def main(argv=None):
    formats = {
        ("po", "py"): ("py", convertpy),
        ("po", None): ("py", convertpy)
    }
    parser = convert.ConvertOptionParser(formats, usetemplates=False, description=__doc__)
    parser.add_threshold_option()
    parser.add_fuzzy_option()
    parser.run(argv)


if __name__ == '__main__':
    main()
